[![Python](https://img.shields.io/pypi/pyversions/thya)](https://img.shields.io/pypi/pyversions/thya)
[![Pypi](https://img.shields.io/pypi/v/thya)](https://pypi.org/project/thya/)
[![Downloads](https://static.pepy.tech/personalized-badge/thya?period=month&units=international_system&left_color=grey&right_color=brightgreen&left_text=PyPI%20downloads/month)](https://pepy.tech/project/thya)
[![Downloads](https://static.pepy.tech/personalized-badge/thya?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/thya)
[![License](https://img.shields.io/badge/license-AGPLv3-green)](https://github.com/ThyaTechnology/thya/blob/master/LICENSE)


# Thya Technology Package